@@ -1,28 +1,16 @@
-/* This file is part of the KDE libraries
-    Copyright (C) 2006 Aaron Seigo <aseigo@kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2006 Aaron Seigo <aseigo@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "knotificationrestrictions.h"
 
 #include <QApplication>
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusMessage>
-#include <QtDBus/QDBusReply>
+#include <QDBusConnection>
+#include <QDBusMessage>
+#include <QDBusReply>
 
 #include <config-knotifications.h>
 #include "debug_p.h"
@@ -35,7 +23,7 @@
 #include <X11/extensions/XTest.h>
 #endif // HAVE_XTEST
 
-class KNotificationRestrictions::Private
+class Q_DECL_HIDDEN KNotificationRestrictions::Private
 {
 public:
     Private(KNotificationRestrictions *qq, Services c, const QString &r)
@@ -155,7 +143,7 @@ void KNotificationRestrictions::Private::startScreenSaverPrevention()
 
     qCDebug(LOG_KNOTIFICATIONS) << "---- using XTest";
     // send a fake event right away in case this got started after a period of
-    // innactivity leading to the screensaver set to activate in <55s
+    // inactivity leading to the screensaver set to activate in <55s
     screensaverFakeKeyEvent();
     screensaverTimer->start(55000);
 #endif // HAVE_XTEST
