@@ -2,8 +2,7 @@
 #include <QApplication>
 #include <kpassivepopup.h>
 #include <QPushButton>
-#include <QLatin1String>
-#include <qsystemtrayicon.h>
+#include <QSystemTrayIcon>
 
 #include <kwindowsystem.h>
 
